"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.load = void 0;
const typedoc_1 = require("typedoc");
const plugin_1 = require("./plugin");
const fs_1 = require("fs");
const path_1 = require("path");
const events_1 = require("typedoc/dist/lib/output/events");
function load(app) {
    app.options.addDeclaration({
        name: 'favicon',
        help: 'Extras Plugin: Specify the name of the favicon file.',
        type: typedoc_1.ParameterType.String,
        defaultValue: undefined
    });
    app.options.addDeclaration({
        name: 'footerTypedocVersion',
        help: 'Extras Plugin: Appends the TypeDoc version in the footer.',
        type: typedoc_1.ParameterType.Boolean,
        defaultValue: false
    });
    app.options.addDeclaration({
        name: 'footerDate',
        help: 'Extras Plugin: Appends the date of generation in the footer.',
        type: typedoc_1.ParameterType.Boolean,
        defaultValue: false
    });
    app.options.addDeclaration({
        name: 'footerTime',
        help: 'Extras Plugin: Appends the time of generation in the footer.',
        type: typedoc_1.ParameterType.Boolean,
        defaultValue: false
    });
    app.renderer.addComponent('extras', new plugin_1.ExtrasPlugin(app.renderer));
    app.renderer.once(events_1.RendererEvent.END, () => {
        const faviconPath = app.options.getValue('favicon');
        if (!faviconPath)
            return;
        const workingDir = process.cwd();
        const outDir = app.options.getValue('out') || './docs';
        const inputFavicon = (faviconPath.indexOf(workingDir) === -1) ?
            (0, path_1.join)(workingDir, faviconPath) : faviconPath;
        const outputFavicon = (outDir.indexOf(workingDir) === -1) ?
            (0, path_1.join)(workingDir, outDir, (0, path_1.basename)(faviconPath)) : (0, path_1.join)(outDir, (0, path_1.basename)(faviconPath));
        (0, fs_1.copyFileSync)(inputFavicon, outputFavicon);
    });
}
exports.load = load;
//# sourceMappingURL=index.js.map