"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.load = void 0;
const typedoc_1 = require("typedoc");
const helpers_1 = require("./helpers");
const path_1 = require("path");
const fs_1 = require("fs");
const TYPEDOC_VERSION = typedoc_1.Application.VERSION;
const pluginOptions = (app) => ({
    options: () => ({
        outDir: app.options.getValue('out'),
        hideGenerator: app.options.getValue('hideGenerator'),
        faviconPath: app.options.getValue('favicon'),
        footerDate: app.options.getValue('footerDate'),
        footerTime: app.options.getValue('footerTime'),
        footerTypedocVersion: app.options.getValue('footerTypedocVersion'),
    })
});
function load(app) {
    app.options.addDeclaration({
        name: 'favicon',
        help: 'Extras Plugin: Specify the name of the favicon file.',
        type: typedoc_1.ParameterType.String,
        defaultValue: undefined
    });
    app.options.addDeclaration({
        name: 'footerTypedocVersion',
        help: 'Extras Plugin: Appends the TypeDoc version in the footer.',
        type: typedoc_1.ParameterType.Boolean,
        defaultValue: false
    });
    app.options.addDeclaration({
        name: 'footerDate',
        help: 'Extras Plugin: Appends the date of generation in the footer.',
        type: typedoc_1.ParameterType.Boolean,
        defaultValue: false
    });
    app.options.addDeclaration({
        name: 'footerTime',
        help: 'Extras Plugin: Appends the time of generation in the footer.',
        type: typedoc_1.ParameterType.Boolean,
        defaultValue: false
    });
    const options = pluginOptions(app);
    app.renderer.on(typedoc_1.PageEvent.END, onPageRendered.bind(options));
    app.renderer.once(typedoc_1.RendererEvent.END, onRenderFinished.bind(options));
}
exports.load = load;
function onPageRendered(page) {
    if (!page.contents)
        return;
    const options = this.options();
    // Add icon.
    if (options.faviconPath) {
        const faviconFilename = (0, path_1.basename)(options.faviconPath);
        const faviconUrl = (0, helpers_1.makeRelativeToRoot)(page.url, faviconFilename);
        page.contents = (0, helpers_1.appendFavicon)(page.contents, faviconUrl);
    }
    // Add TypeDoc version.
    if (options.footerTypedocVersion) {
        page.contents = (0, helpers_1.appendToFooter)(page.contents, ` version ${TYPEDOC_VERSION}`);
    }
    // Add generation date and/or time.
    if (!options.hideGenerator && (options.footerDate || options.footerTime)) {
        const now = new Date();
        const date = ` the ${now.toLocaleDateString()}`;
        const time = ` at ${now.toLocaleTimeString()}`;
        let dateTime = ',';
        if (options.footerDate)
            dateTime += date;
        if (options.footerTime)
            dateTime += time;
        page.contents = (0, helpers_1.appendToFooter)(page.contents, dateTime);
    }
}
function onRenderFinished() {
    const options = this.options();
    // Copy favicon to output directory.
    if (options.faviconPath) {
        const workingDir = process.cwd();
        const outDir = options.outDir || './docs';
        const inputFavicon = (options.faviconPath.indexOf(workingDir) === -1) ?
            (0, path_1.join)(workingDir, options.faviconPath) : options.faviconPath;
        const outputFavicon = (outDir.indexOf(workingDir) === -1) ?
            (0, path_1.join)(workingDir, outDir, (0, path_1.basename)(options.faviconPath)) : (0, path_1.join)(outDir, (0, path_1.basename)(options.faviconPath));
        (0, fs_1.copyFileSync)(inputFavicon, outputFavicon);
    }
}
//# sourceMappingURL=main.js.map