"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExtrasPlugin = void 0;
const helpers_1 = require("./helpers");
const components_1 = require("typedoc/dist/lib/output/components");
const events_1 = require("typedoc/dist/lib/output/events");
const path_1 = require("path");
// const TYPEDOC_VERSION = require('typedoc/package.json').version;
class ExtrasPlugin extends components_1.RendererComponent {
    initialize() {
        this.listenTo(this.owner, events_1.PageEvent.END, this.onRendererEndPage);
    }
    onRendererEndPage(page) {
        if (!page.contents)
            return;
        const hideGenerator = this.application.options.getValue('hideGenerator');
        const favicon = (0, path_1.basename)(this.application.options.getValue('favicon'));
        const footerDate = this.application.options.getValue('footerDate');
        const footerTime = this.application.options.getValue('footerTime');
        const footerTypedocVersion = this.application.options.getValue('footerTypedocVersion');
        // Add icon.
        if (favicon) {
            const faviconUrl = (0, helpers_1.makeRelativeToRoot)(page.url, favicon);
            page.contents = (0, helpers_1.appendFavicon)(page.contents, faviconUrl);
        }
        // Add TypeDoc version.
        if (footerTypedocVersion) {
            // page.contents = appendToFooter(page.contents, ` version ${TYPEDOC_VERSION}`);
        }
        // Add generation date and/or time.
        if (!hideGenerator && (footerDate || footerTime)) {
            const now = new Date();
            const date = ` the ${now.toLocaleDateString()}`;
            const time = ` at ${now.toLocaleTimeString()}`;
            let dateTime = ',';
            if (footerDate)
                dateTime += date;
            if (footerTime)
                dateTime += time;
            page.contents = (0, helpers_1.appendToFooter)(page.contents, dateTime);
        }
    }
}
exports.ExtrasPlugin = ExtrasPlugin;
//# sourceMappingURL=plugin.js.map